'use client';
import Head from "next/head";
import { useEffect } from "react";
import { useSession } from "next-auth/react";
import { closeSession } from "@/feature/messenger/utils/CloseSession";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { useRouter } from "next/navigation";
import { I18nextProvider } from 'react-i18next';
import i18n from '@/i18n';
import PushNotificationHandler from "@/src/utils/PushNotificationHelper";
import Script from "next/script";

export default function ChatMessengerLayout({ children }: Readonly<{ children: React.ReactNode; }>) {
  const { status } = useSession();
  const router = useRouter();
  const id_chatbot = useConfigChatStore(state => state.idChatbot);

  useEffect(() => {
    if (status === "unauthenticated") {
      closeSession();
    }
    if (id_chatbot == "") {
      router.push(`/chat/select`);
    }
  }, [status])
  return (
    <>
      <Head>
        <title>Multi Agente</title>
        <link rel="icon" href="/favicon.ico" />
      </Head>
      <Script src={`${process.env.ASSET_PREFIX}/push.min.js`} defer />
      <div id="__next">
        <I18nextProvider i18n={i18n}>
          {children}
          <PushNotificationHandler />
        </I18nextProvider>
      </div>
    </>

  );
}
